@@ -1,22 +1,21 @@
-get.smiles <- function(molecule) {
+get.smiles <- function(molecule, type = 'generic', aromatic=FALSE, atomClasses=FALSE) {
   if (attr(molecule, "jclass") != 'org/openscience/cdk/interfaces/IAtomContainer') {
     stop("Supplied object should be a Java reference to an IAtomContainer")
   }
-  smiles <- .jcall('org/guha/rcdk/util/Misc', 'S', 'getSmiles', molecule)
+  smiles <- .jcall('org/guha/rcdk/util/Misc', 'S', 'getSmiles', molecule, as.character(type), as.logical(aromatic), as.logical(atomClasses))
   smiles
 }
 
 get.smiles.parser <- function() {
-  dcob <- .jcall("org/openscience/cdk/DefaultChemObjectBuilder",
-                 "Lorg/openscience/cdk/interfaces/IChemObjectBuilder;",
-                 "getInstance")
+  dcob <- .get.chem.object.builder()
   .jnew("org/openscience/cdk/smiles/SmilesParser", dcob)
 }
-parse.smiles <- function(smiles) {
+parse.smiles <- function(smiles, kekulise=TRUE) {
   if (!is.character(smiles)) {
     stop("Must supply a character vector of SMILES strings")
   }
   parser <- get.smiles.parser()
+  .jcall(parser, "V", "kekulise", kekulise)
   returnValue <- sapply(smiles, 
       function(x) {
         mol <- .jcall(parser, "Lorg/openscience/cdk/interfaces/IAtomContainer;", "parseSmiles", x)    
